@@ -14,7 +14,7 @@
 #
 #############################################################################
 #
-# $Id: ChainMgr.pm,v 1.16 2005/03/23 02:39:16 mbr Exp $
+# $Id: ChainMgr.pm 1506 2005-12-18 20:13:58Z mbr $
 #
 
 package IPTables::ChainMgr;
@@ -325,11 +325,6 @@ sub find_ip_rule() {
     my $extended_href = shift || {};
     my $iptables = $self->{'_iptables'};
 
-    ### first make sure the chain actually exists
-    unless ($self->chain_exists($table, $chain, $iptables)) {
-        return 0;
-    }
-
     my $ipt_parse = new IPTables::Parse('iptables' => $iptables)
         or croak "[*] Could not acquire IPTables::Parse object";
 
