@@ -7,11 +7,11 @@
 #
 # Author: Michael Rash (mbr@cipherdyne.org)
 #
-# Version: 0.2
+# Version: 0.3
 #
 ##################################################################
 #
-# $Id: Parse.pm,v 1.7 2005/10/24 02:29:58 mbr Exp $
+# $Id: Parse.pm 1501 2005-12-18 18:37:09Z mbr $
 #
 
 package IPTables::Parse;
@@ -22,7 +22,7 @@ use strict;
 use warnings;
 use vars qw($VERSION);
 
-$VERSION = '0.2';
+$VERSION = '0.3';
 
 sub new() {
     my $class = shift;
@@ -229,7 +229,7 @@ sub default_drop() {
         next LINE unless $found_chain;
 
         ### include ULOG target as well
-        if ($line =~ m|^\s*U?LOG\s+(\w+)\s+\-\-\s+
+        if ($line =~ m|^\s*U?LOG\s+(\w+)\s+\-\-\s+.*
             $any_ip_re\s+$any_ip_re\s+(.*)|x) {
             my $proto  = $1;
             my $p_tmp  = $2;
@@ -242,7 +242,7 @@ sub default_drop() {
             ### $proto may equal "all" here
             $protocols{$proto}{'LOG'}{'prefix'} = $prefix;
             $protocols{$proto}{'LOG'}{'rulenum'} = $rule_ctr;
-        } elsif ($policy eq 'ACCEPT' and $line =~ m|^DROP\s+(\w+)\s+\-\-\s+
+        } elsif ($policy eq 'ACCEPT' and $line =~ m|^DROP\s+(\w+)\s+\-\-\s+.*
             $any_ip_re\s+$any_ip_re\s*$|x) {
             ### DROP    all  --  0.0.0.0/0     0.0.0.0/0
             $protocols{$1}{'DROP'} = $rule_ctr;
@@ -305,8 +305,9 @@ sub default_log() {
         $log_chain = '' unless $line =~ /\S/;
         next unless $log_chain;
 
-        if ($line =~ m|^\s*U?LOG\s+(\w+)\s+\-\-\s+$any_ip_re
-            \s+$any_ip_re\s+U?LOG|x) {
+        if ($line =~ m|^\s*U?LOG\s+(\w+)\s+\-\-\s+.*$any_ip_re
+                \s+$any_ip_re\s+.*U?LOG|x) {
+            ### the above regex allows the limit target to be used
             $log_chains{$log_chain}{$1} = '';  ### protocol
 
             if ($log_chain eq $chain) {
