@@ -12,7 +12,7 @@
 #
 ##################################################################
 #
-# $Id: Psad.pm,v 1.10 2005/11/08 04:33:21 mbr Exp $
+# $Id: Psad.pm 1532 2006-04-25 02:09:12Z mbr $
 #
 
 package Psad;
@@ -190,8 +190,8 @@ sub sendmail() {
 ### write a message to syslog
 sub psyslog() {
     my ($ident, $msg) = @_;
-    openlog $ident, LOG_DAEMON, LOG_LOCAL7;
-    syslog LOG_INFO, $msg;
+    openlog($ident, &LOG_DAEMON(), &LOG_LOCAL7());
+    syslog(&LOG_INFO(), $msg);
     closelog();
     return;
 }
