@@ -13,7 +13,7 @@
 #
 # Credits: (see the CREDITS file bundled with the psad sources.)
 #
-# Copyright (C) 1999-2002 Michael Rash (mbr@cipherdyne.org)
+# Copyright (C) 1999-2006 Michael Rash (mbr@cipherdyne.org)
 #
 # License (GNU Public License):
 #
@@ -29,7 +29,7 @@
 #
 ###############################################################################
 #
-# $Id: fwcheck_psad.pl,v 1.24 2005/03/19 03:58:12 mbr Exp $
+# $Id: fwcheck_psad.pl 1548 2006-06-03 17:14:41Z mbr $
 #
 
 use lib '/usr/lib/psad';
@@ -195,7 +195,7 @@ sub print_fw_help() {
 "[-] You may just need to add a default logging rule to the $chain chain on\n",
 "    $config{'HOSTNAME'}.  For more information, see the file \"FW_HELP\" in\n",
 "    the psad sources directory or visit:\n\n",
-"    http://www.cipherdyne.org/psad/fw_config.html\n\n";
+"    http://www.cipherdyne.org/psad/docs/fwconfig.html\n\n";
     return;
 }
 
