@@ -11,7 +11,7 @@
 #
 # Credits:  (see the CREDITS file)
 #
-# Copyright (C) 1999-2002 Michael Rash (mbr@cipherdyne.org)
+# Copyright (C) 1999-2006 Michael Rash (mbr@cipherdyne.org)
 #
 # License (GNU Public License):
 #
@@ -29,7 +29,7 @@
 #
 #########################################################################
 #
-# $Id: install.pl,v 1.233 2005/10/26 02:21:12 mbr Exp $
+# $Id: install.pl 1543 2006-05-29 17:03:56Z mbr $
 #
 
 use Cwd;
@@ -104,7 +104,7 @@ my %required_perl_modules = (
         'mod-dir' => 'Net-IPv4Addr'
     },
     'IPTables::Parse' => {
-        'version' => '0.2',
+        'version' => '0.3',
         'force-lib-install' => 1,
         'mod-dir' => 'IPTables-Parse'
     },
@@ -343,22 +343,22 @@ sub install() {
         &install_perl_module($module);
     }
 
-    &logr("[+] Installing Snort-2.3 signatures in $SNORT_DIR\n");
+    &logr("[+] Installing Snort-2.3.3 signatures in $SNORT_DIR\n");
     unless (-d $SNORT_DIR) {
         mkdir $SNORT_DIR, 0500 or die "[*] Could not create $SNORT_DIR: $!";
     }
     opendir D, 'snort_rules' or die "[*] Could not open ",
         'the snort_rules directory';
-    my @rfiles = readdir D;
+    my @files = readdir D;
     closedir D;
-    shift @rfiles; shift @rfiles;
-    for my $rfile (@rfiles) {
-        next unless $rfile =~ /\.rules$/;
-        &logr("[+] Installing snort_rules/${rfile}\n");
-        copy "snort_rules/${rfile}", "${SNORT_DIR}/${rfile}" or
-            die "[*] Could not copy snort_rules/${rfile} -> ",
-                "${SNORT_DIR}/${rfile}: $!";
-        &perms_ownership("${SNORT_DIR}/${rfile}", 0600);
+    shift @files; shift @files;
+    for my $file (@files) {
+        next unless $file =~ /\.rules$/ or $file =~ /\.config$/;
+        &logr("[+] Installing snort_rules/${file}\n");
+        copy "snort_rules/${file}", "${SNORT_DIR}/${file}" or
+            die "[*] Could not copy snort_rules/${file} -> ",
+                "${SNORT_DIR}/${file}: $!";
+        &perms_ownership("${SNORT_DIR}/${file}", 0600);
     }
     print "\n\n";
 
@@ -377,7 +377,7 @@ sub install() {
         unless (((system "$Cmds{'perl'} -c kmsgsd.pl")>>8) == 0) {
             die "[*] kmsgsd.pl does not compile with \"perl -c\".  ",
                 "Download the latest sources " .
-                "from:\n\nhttp://www.cipherdyne.org\n";
+                "from:\n\nhttp://www.cipherdyne.org/\n";
         }
         copy 'kmsgsd.pl', 'kmsgsd' or die "[*] Could not copy ",
             "kmsgsd.pl -> kmsgsd: $!";
@@ -388,7 +388,7 @@ sub install() {
         unless (((system "$Cmds{'perl'} -c psadwatchd.pl")>>8) == 0) {
             die "[*] psadwatchd.pl does not compile with \"perl -c\".  ",
                 "Download the latest sources " .
-                "from:\n\nhttp://www.cipherdyne.org\n";
+                "from:\n\nhttp://www.cipherdyne.org/\n";
         }
         copy 'psadwatchd.pl', 'psadwatchd' or die "[*] Could not copy ",
             "psadwatchd.pl -> psadwatchd: $!";
@@ -399,7 +399,7 @@ sub install() {
     &logr("[+] Verifying compilation of fwcheck_psad.pl script:\n");
     unless (((system "$Cmds{'perl'} -c fwcheck_psad.pl")>>8) == 0) {
         die "[*] fwcheck_psad.pl does not compile with \"perl -c\".  Download ",
-            "the latest sources from:\n\nhttp://www.cipherdyne.org\n";
+            "the latest sources from:\n\nhttp://www.cipherdyne.org/\n";
     }
 
     ### make sure the psad (perl) daemon compiles.  The other three
@@ -407,7 +407,7 @@ sub install() {
     &logr("[+] Verifying compilation of psad perl daemon:\n");
     unless (((system "$Cmds{'perl'} -c psad")>>8) == 0) {
         die "[*] psad does not compile with \"perl -c\".  Download the",
-            " latest sources from:\n\nhttp://www.cipherdyne.org\n";
+            " latest sources from:\n\nhttp://www.cipherdyne.org/\n";
     }
     print "\n\n";
 
@@ -490,7 +490,7 @@ sub install() {
     }
 
     ### install auto_dl, signatures, icmp_types, posf, and pf.os files
-    for my $file qw(signatures icmp_types posf auto_dl pf.os) {
+    for my $file qw(signatures icmp_types posf auto_dl snort_rule_dl pf.os) {
         if (-e "${PSAD_CONFDIR}/$file") {
             &archive("${PSAD_CONFDIR}/$file") unless $noarchive;
             unless (&query_preserve_sigs_autodl("${PSAD_CONFDIR}/$file")) {
@@ -911,7 +911,7 @@ sub install_perl_module() {
         unless (-e 'Makefile.PL') {
             die "[*] Your $mod_name source directory appears to be incomplete!\n",
                 "    Download the latest sources from ",
-                "http://www.cipherdyne.org\n";
+                "http://www.cipherdyne.org/\n";
         }
         system "$Cmds{'make'} clean" if -e 'Makefile';
         system "$Cmds{'perl'} Makefile.PL PREFIX=$LIBDIR LIB=$LIBDIR";
@@ -1043,7 +1043,7 @@ sub set_hostname() {
     } else {
         die "[*] Your source directory appears to be incomplete!  $file ",
             "is missing.\n    Download the latest sources from ",
-            "http://www.cipherdyne.org\n";
+            "http://www.cipherdyne.org/\n";
     }
     return;
 }
@@ -1918,10 +1918,10 @@ sub logr() {
 }
 
 sub usage() {
-        my $exitcode = shift;
-        print <<_HELP_;
+    my $exitcode = shift;
+    print <<_HELP_;
 
-Usage: install.pl [-f] [-s <file> ] [-u] [--no-syslog-test]
+Usage: install.pl [-f] [-s <file>] [-u] [--no-syslog-test]
                   [--no-preserve] [-h]
 
     -u  --uninstall     - Uninstall psad.
@@ -1934,5 +1934,5 @@ Usage: install.pl [-f] [-s <file> ] [-u] [--no-syslog-test]
     -h  --help          - Prints this help message.
 
 _HELP_
-        exit $exitcode;
+    exit $exitcode;
 }
