@@ -14,7 +14,7 @@
 *
 *  Credits:  (see the CREDITS file)
 *
-*  Copyright (C) 1999-2001 Michael Rash (mbr@cipherdyne.org)
+*  Copyright (C) 1999-2006 Michael Rash (mbr@cipherdyne.org)
 *
 *  License (GNU Public License):
 *
@@ -29,7 +29,7 @@
 *     USA
 ******************************************************************************
 *
-*  $Id: kmsgsd.c,v 1.50 2005/10/13 03:44:40 mbr Exp $
+*  $Id: kmsgsd.c 1533 2006-04-25 02:09:55Z mbr $
 */
 
 /* includes */
@@ -198,8 +198,8 @@ int main(int argc, char *argv[]) {
 
         /* see if we matched a firewall message and write it to the
          * fwdata file */
-        if ((strstr(buf, "OUT") != NULL
-                && strstr(buf, "IN") != NULL)) {
+        if ((strstr(buf, "OUT=") != NULL
+                && strstr(buf, "IN=") != NULL)) {
             if (! fw_search_all_flag) {  /* we are looking for specific log prefixes */
                 if (match_fw_msg(buf) || strstr(buf, snort_sid_str) != NULL) {
                     if (write(fwdata_fd, buf, numbytes) < 0) {
